import ArtistInfoBox from "@/components/images/ArtistInfoBox";
import GlowingImageWithToggle from "@/components/images/GlowingImageWithToggle";
import ImageMetadataBox from "@/components/images/ImageMetadataBox";
import prisma from "@/lib/prisma";
import Link from "next/link";

export default async function ImagePage({ params }: { params: { gallerySlug: string, albumSlug: string, imageId: string } }) {
  const { imageId } = await params;

  const image = await prisma.image.findUnique({
    where: {
      id: imageId
    },
    include: {
      artist: { include: { socials: true } },
      colors: { include: { color: true } },
      extractColors: { include: { extract: true } },
      palettes: { include: { palette: { include: { items: true } } } },
      album: true,
      categories: true,
      tags: true,
      variants: true,
      metadata: true,
      stats: true
    }
  })

  if (!image) return <div>Image not found</div>

  const resizedVariant = image.variants.find(v => v.type === "resized");

  return (
    <div>
      {image && (
        <div className="flex flex-col items-center">
          <div>
            <h1 className="text-2xl font-bold mb-4 pb-8">{image.imageName}</h1>
          </div>

          {resizedVariant &&
            <Link href={`/raw/${image.id}`} passHref>
              <GlowingImageWithToggle
                alt={image.imageName}
                variant={resizedVariant}
                colors={image.colors}
                src={`/api/image/${resizedVariant.s3Key}`}
                nsfw={image.nsfw}
              />
            </Link>
          }
          <section className="py-8 flex flex-col gap-4">
            {image.artist && <ArtistInfoBox artist={image.artist} />}

            <div className="rounded-lg border p-6 space-y-4">
              <h2 className="text-xl font-semibold mb-2">Image Metadata</h2>

              <p><strong>Name:</strong> {image.imageName}</p>
              {image.altText && <p><strong>Alt Text:</strong> {image.altText}</p>}
              {image.description && <p><strong>Description:</strong> {image.description}</p>}
              {/* <p><strong>NSFW:</strong> {image.nsfw ? "Yes" : "No"}</p>
                <p><strong>Upload Date:</strong> {new Date(image.uploadDate).toLocaleDateString()}</p>
                {image.source && <p><strong>Source:</strong> {image.source}</p>}
                {image.fileType && <p><strong>File Type:</strong> {image.fileType}</p>}
                {image.fileSize && <p><strong>Size:</strong> {(image.fileSize / 1024).toFixed(1)} KB</p>}
                {image.creationDate && (
                  <p><strong>Created:</strong> {new Date(image.creationDate).toLocaleDateString()}</p>
                )}
                {image.creationYear && image.creationMonth && (
                  <p><strong>Creation:</strong> {image.creationMonth}/{image.creationYear}</p>
                )} */}

              {/* {image.metadata && (
                  <>
                    <h3 className="text-lg font-medium mt-4">Metadata</h3>
                    <p><strong>Width:</strong> {image.metadata.width}px</p>
                    <p><strong>Height:</strong> {image.metadata.height}px</p>
                    <p><strong>Format:</strong> {image.metadata.format}</p>
                    <p><strong>Color Space:</strong> {image.metadata.space}</p>
                    <p><strong>Channels:</strong> {image.metadata.channels}</p>
                    {image.metadata.bitsPerSample && (
                      <p><strong>Bits Per Sample:</strong> {image.metadata.bitsPerSample}</p>
                    )}
                    {image.metadata.hasAlpha !== null && (
                      <p><strong>Has Alpha:</strong> {image.metadata.hasAlpha ? "Yes" : "No"}</p>
                    )}
                  </>
                )} */}

              {/* {image.stats && (
                  <>
                    <h3 className="text-lg font-medium mt-4">Statistics</h3>
                    <p><strong>Entropy:</strong> {image.stats.entropy.toFixed(2)}</p>
                    <p><strong>Sharpness:</strong> {image.stats.sharpness.toFixed(2)}</p>
                    <p><strong>Dominant Color:</strong> rgb({image.stats.dominantR}, {image.stats.dominantG}, {image.stats.dominantB})</p>
                    <p><strong>Is Opaque:</strong> {image.stats.isOpaque ? "Yes" : "No"}</p>
                  </>
                )} */}
            </div>

            <ImageMetadataBox
              album={image.album}
              categories={image.categories}
              tags={image.tags}
            />
          </section>
        </div>
      )}
    </div >
  );
}